package lightcontainer.repository;

import lightcontainer.interfaces.ProtocolRepository;
import lightcontainer.protocol.ProtocolReader;
import lightcontainer.protocol.ProtocolWriter;

import java.util.HashSet;
import java.util.Set;

public class ProtocolRepositoryImpl implements ProtocolRepository {
    private Set<ProtocolReader> readers = new HashSet<>();
    private Set<ProtocolWriter> writers = new HashSet<>();

    @Override
    public boolean executeReader(String data) {
        for (ProtocolReader reader : readers) {
            if (reader.execute(data)) {
                return true;
            }
        }
        return false;
    }

    @Override
    public String executeWriter(String... datas) {
        for (ProtocolWriter writer : writers) {
            String command = writer.execute(datas);
            if (command != null) {
                return command;
            }
        }
        return null;
    }

    @Override
    public void addReader(ProtocolReader reader) {
        this.readers.add(reader);
    }

    @Override
    public void addWriter(ProtocolWriter writer) {
        this.writers.add(writer);
    }
}
